@@ -29,7 +29,7 @@ use GnuPG::Options;
 use GnuPG::Handles;
 use Scalar::Util 'tainted';
 
-$VERSION = '1.01';
+$VERSION = '1.03';
 
 has passphrase => (
     isa     => 'Any',
@@ -336,6 +336,13 @@ sub fork_attach_exec( $% ) {
         }
 
         my @args = $self->options->get_args();
+
+        # Get around a bug in 2.2, see also https://dev.gnupg.org/T4667
+        # this covers both --delete-secret-key(s) and --delete-secret-and-public-key(s)
+        if ( $self->version && $self->cmp_version( $self->version, 2.2 ) >= 0 && $commands[0] =~ /^--delete-secret-.*keys?$/ ) {
+            push @args, '--yes';
+        }
+
         push @args, '--pinentry-mode', 'loopback'
           if $use_loopback_pinentry;
 
@@ -344,7 +351,11 @@ sub fork_attach_exec( $% ) {
             @commands,     @command_args
         );
 
-        local $ENV{PATH} if tainted $ENV{PATH};
+        # On Unix, PATH is by default '.' and Perl >= v5.38 rejects '.'
+        # being in the path when in taint mode. Set a path, if running
+        # in taint mode whomever is calling us should be providing the
+        # path to the gpg program to use.
+        local $ENV{PATH} = '/usr/bin' if tainted $ENV{PATH};
         exec @command or die "exec() error: $ERRNO";
     }
 
