@@ -14,12 +14,10 @@
 #
 
 package GnuPG::PublicKey;
-use Any::Moose;
+use Moo;
 
 BEGIN { extends qw( GnuPG::PrimaryKey ) }
 
-__PACKAGE__->meta->make_immutable;
-
 1;
 
 __END__
@@ -42,7 +40,7 @@ through various methods of GnuPG::Interface.
 They embody various aspects of a GnuPG public key.
 
 This package inherits data members and object methods
-from GnuPG::PrimaryKey, which is described here, but rather
+from GnuPG::PrimaryKey, which is not described here, but rather
 in L<GnuPG::PrimaryKey>.
 
 Currently, this package is functionally no different
